
# Slot: interacting molecules category




URI: [biolink:interacting_molecules_category](https://w3id.org/biolink/vocab/interacting_molecules_category)


## Domain and Range

[Association](Association.md) &#8594;  <sub>0..1</sub> [OntologyClass](OntologyClass.md)

## Parents

 *  is_a: [association slot](association_slot.md)

## Children


## Used by

 * [PairwiseMolecularInteraction](PairwiseMolecularInteraction.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Examples:** | | Example(value='MI:1048', description='smallmolecule-protein') |
| **Exact Mappings:** | | MI:1046 |

